==> biopipen-0.21.1.tar.gz: biopipen-0.21.1/biopipen/scripts/tcr/Immunarch-tracking.R <==
print("- Clonotype tracking")

trackings = {{ envs.trackings | r }}

if (is.null(trackings$subjects)) {
    trackings$subjects = c()
}
if (length(trackings$cases) == 0) {
    trackings$cases$DEFAULT = list(
        targets = trackings$targets,
        subject_col = trackings$subject_col,
        subjects = trackings$subjects
    )
} else {
    for (name in names(trackings$cases)) {
        if (is.null(trackings$cases[[name]]$targets)) {
            trackings$cases[[name]]$targets = trackings$targets
        }
        if (is.null(trackings$cases[[name]]$subject_col)) {
            trackings$cases[[name]]$subject_col = trackings$subject_col
        }
        if (is.null(trackings$cases[[name]]$subjects)) {
            trackings$cases[[name]]$subjects = trackings$subjects
        }
        if (is.null(trackings$cases[[name]]$subset)) {
            trackings$cases[[name]]$subset = trackings$subset
        }
    }
}

tracking_dir = file.path(outdir, "tracking")
dir.create(tracking_dir, showWarnings = FALSE)

run_tracking_case = function(casename) {
    case = trackings$cases[[casename]]

    if (!is.null(case$subset)) {
        d = immdata_from_expanded(filter_expanded_immdata(exdata, case$subset))
    } else {
        d = immdata
    }

    if (is.null(case$targets)) {
        print(paste0("  ", casename, ", skip, no targets"))
    } else {
        print(paste0("  ", casename))
        allsubjects = d$meta %>% pull(case$subject_col) %>% unlist() %>% unique() %>% na.omit()
        if (is.null(case$subjects) || length(case$subjects) == 0) {
            subjects = allsubjects
        } else {
            subjects = intersect(case$subjects, allsubjects)
        }
        if (length(allsubjects) == 1) {
            stop(paste0("Cannot track clonotypes for only one subject: ", subjects))
        }
        samples = d$meta[d$meta[[case$subject_col]] %in% subjects, ] %>% pull(Sample) %>% unlist()
        if (is.numeric(case$targets)) {
            targets = do_call(rbind, lapply(samples, function(s) d$data[[s]])) %>%
                group_by(CDR3.aa) %>%
                summarise(Clones = sum(Clones)) %>%
                arrange(desc(Clones)) %>%
                slice_max(Clones, n=case$target) %>%
                pull(CDR3.aa)
        } else {
            targets = case$targets
        }
        if (case$subject_col == "Sample") {
            imm_tracking = trackClonotypes(d$data, targets, .col = "aa")
        } else {
            # Construct a data with names as subjects
            # For each subject, get the samples and merge the data
            # Then track
            newdata = list()
            for (subject in subjects) {
                subject_samples = d$meta[d$meta[[case$subject_col]] == subject, ] %>%
                    pull(Sample) %>%
                    na.omit()
                newdata[[subject]] = do_call(rbind, lapply(subject_samples, function(s) d$data[[s]]))
            }
            imm_tracking = trackClonotypes(newdata, targets, .col = "aa")
        }

        tracking_png = file.path(tracking_dir, paste0(casename, ".png"))
        png(tracking_png, res=100, height=1000, width=600 + 150 * length(subjects))
        print(vis(imm_tracking))
        dev.off()
    }
}

sapply(names(trackings$cases), run_tracking_case)

==> biopipen-0.21.2.tar.gz: biopipen-0.21.2/biopipen/scripts/tcr/Immunarch-tracking.R <==
log_info("")
log_info("#####################################")
log_info("# Clonotype tracking                #")
log_info("#####################################")

trackings = {{ envs.trackings | r }}

log_info("Filling up cases ...")
if (is.null(trackings$subjects)) {
    trackings$subjects = c()
}
if (length(trackings$cases) == 0) {
    trackings$cases$DEFAULT = list(
        targets = trackings$targets,
        subject_col = trackings$subject_col,
        subjects = trackings$subjects
    )
} else {
    for (name in names(trackings$cases)) {
        if (is.null(trackings$cases[[name]]$targets)) {
            trackings$cases[[name]]$targets = trackings$targets
        }
        if (is.null(trackings$cases[[name]]$subject_col)) {
            trackings$cases[[name]]$subject_col = trackings$subject_col
        }
        if (is.null(trackings$cases[[name]]$subjects)) {
            trackings$cases[[name]]$subjects = trackings$subjects
        }
        if (is.null(trackings$cases[[name]]$subset)) {
            trackings$cases[[name]]$subset = trackings$subset
        }
    }
}

tracking_dir = file.path(outdir, "tracking")
dir.create(tracking_dir, showWarnings = FALSE)

run_tracking_case = function(casename) {
    case = trackings$cases[[casename]]

    if (!is.null(case$subset)) {
        d = immdata_from_expanded(filter_expanded_immdata(exdata, case$subset))
    } else {
        d = immdata
    }

    if (is.null(case$targets)) {
        # print(paste0("  ", casename, ", skip, no targets"))
        log_info("- Case: {casename}, skip, no targets")
    } else {
        # print(paste0("  ", casename))
        log_info("- Case: {casename}")
        allsubjects = d$meta %>% pull(case$subject_col) %>% unlist() %>% unique() %>% na.omit()
        if (is.null(case$subjects) || length(case$subjects) == 0) {
            subjects = allsubjects
        } else {
            subjects = intersect(case$subjects, allsubjects)
        }
        if (length(allsubjects) == 1) {
            stop(paste0("Cannot track clonotypes for only one subject: ", subjects))
        }
        samples = d$meta[d$meta[[case$subject_col]] %in% subjects, ] %>% pull(Sample) %>% unlist()
        if (is.numeric(case$targets)) {
            targets = do_call(rbind, lapply(samples, function(s) d$data[[s]])) %>%
                group_by(CDR3.aa) %>%
                summarise(Clones = sum(Clones)) %>%
                arrange(desc(Clones)) %>%
                slice_max(Clones, n=case$target) %>%
                pull(CDR3.aa)
        } else {
            targets = case$targets
        }
        if (case$subject_col == "Sample") {
            imm_tracking = trackClonotypes(d$data, targets, .col = "aa")
        } else {
            # Construct a data with names as subjects
            # For each subject, get the samples and merge the data
            # Then track
            newdata = list()
            for (subject in subjects) {
                subject_samples = d$meta[d$meta[[case$subject_col]] == subject, ] %>%
                    pull(Sample) %>%
                    na.omit()
                newdata[[subject]] = do_call(rbind, lapply(subject_samples, function(s) d$data[[s]]))
            }
            imm_tracking = trackClonotypes(newdata, targets, .col = "aa")
        }

        tracking_png = file.path(tracking_dir, paste0(casename, ".png"))
        png(tracking_png, res=100, height=1000, width=600 + 150 * length(subjects))
        print(vis(imm_tracking))
        dev.off()
    }
}

sapply(names(trackings$cases), run_tracking_case)
